==> haskell-primitive-extras-0.10.2.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-extras
version:              0.10.2.1
visibility:           public
id:                   primitive-extras-0.10.2.1-97Rjwij4YGZGLnIgPAzZIp
key:                  primitive-extras-0.10.2.1-97Rjwij4YGZGLnIgPAzZIp
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  8ffb28353484583d836690314fc4bf05
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.1-97Rjwij4YGZGLnIgPAzZIp
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    deferred-folds-0.9.18.6-G6xTFQdNZYB4FuD7B8752L
    focus-1.0.3.2-Jwfu6oh7j19AuFAutFheaL
    foldl-1.4.17-KiCsilKvBKkJWJpkUDPOYE
    list-t-1.0.5.5-Ft78tdhkAtzGqCkrCJqrNK
    primitive-0.7.4.0-2yvrjkKbYif9hwxczpmLrN
    primitive-unlifted-0.1.3.1-H90jsN2XfY0DtvetUFDIX3
    profunctors-5.6.2-IDT3gQTOCqT1ZN23x5NcdX
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-extras-0.10.2.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-extras
version:              0.10.2.1
visibility:           public
id:                   primitive-extras-0.10.2.1-b7TB3VTSIALHO4xFuvz6o
key:                  primitive-extras-0.10.2.1-b7TB3VTSIALHO4xFuvz6o
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  72a72291453acd906ba88b1dfb12c977
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.1-b7TB3VTSIALHO4xFuvz6o
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    deferred-folds-0.9.18.6-5doWAZeLBQ33tZ8n2Lzzz5
    focus-1.0.3.2-1kxKzDP0mY1KUMC7Tq0fXW
    foldl-1.4.17-B2t4J4toJP27wxx9op8t3h
    list-t-1.0.5.5-FYXF0mARszX1nMJpkb7BS9
    primitive-0.7.4.0-2yvrjkKbYif9hwxczpmLrN
    primitive-unlifted-0.1.3.1-H90jsN2XfY0DtvetUFDIX3
    profunctors-5.6.2-GShwRP90Jtv64Kn3eksX1P
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
